@@ -1,6 +1,6 @@
 # **************************************************************************
 # *
-# * Authors:     Federico P. de Isidro Gomez (fp.deisidro@cnb.csi.es) [1]
+# * Authors:     Federico P. de Isidro Gomez (fp.deisidro@cnb.csic.es) [1]
 # *
 # * [1] Centro Nacional de Biotecnologia, CSIC, Spain
 # *
@@ -26,7 +26,15 @@
 
 from pyworkflow.tests import DataSet
 
-DataSet(name='tomo-em', folder='tomo-em',
+DataSet(name='tomo-em',
+        folder='tomo-em',
         files={
-               'ts1': 'tutorialData/BBa.st',
-               'ts2': 'tutorialData/BBb.st'})
+            'ts1': 'tutorialData/BBa.st',
+            'ts2': 'tutorialData/BBb.st'
+        })
+
+DataSet(name='tutorialDataImodCTF',
+        folder='tutorialDataImodCTF',
+        files={
+            'tsCtf1': 'WTI042413_1series4.st'
+        })
